#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-9pKSxNjPgFA5yvIX0l5Oq5
key:                  gitit-0.15.1.2-9pKSxNjPgFA5yvIX0l5Oq5
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  4ebb7ace39342309b4bec46ae959408f
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-9pKSxNjPgFA5yvIX0l5Oq5
depends:
    HStringTemplate-0.8.8-4DSVzHijzd46W107aGvteR
    HTTP-4000.4.1-2K2yyWBBmX2CXlzoNzKaUm
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.1.0-2aoKFKPwHseOu8oBERSIn base-4.18.2.1
    base64-bytestring-1.2.1.0-9t8HAadP59K2JwXTIu8Svu
    blaze-html-0.9.2.0-8XP9rlaRJVUAs2IV3aWIdq bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-2VjMcPhorLO2Dx0MK9kj30
    feed-1.3.2.1-CgJLOlQcHBCKWOLqL8xJVe filepath-1.4.300.1
    filestore-0.6.5.1-2csFBO5cU8cDv2XgglhhVM ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-EPoX6bLsbc4EgpJZheVzEu
    hoauth2-2.14.0-BCkV9otU5WI402Xezcx8qs
    hslogger-1.3.2.0-FbVp96VOKuRIgqSBytLTxG
    http-client-tls-0.3.6.4-3kKEzWic8zRD5tooTIO7Rk
    http-conduit-2.3.9.1-Ext90YqJUwzLkppzx7C7u1
    json-0.10-KGotMu5dywCC3yIjy3be3p mtl-2.3.1
    network-3.1.4.0-HNp7Plz2T5iBA2k1xbdmYs
    network-bsd-2.8.1.0-6JFNdZwCwkn4ZDnNUV6bL5
    network-uri-2.6.4.2-LbMcOyx90ZBKbCJyfJJvCd
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.4-3lD0LwNFkdkGhWCMuxpBlx
    pandoc-3.6-yz4MxBQukRHdTsFl5F0fw
    pandoc-types-1.23.1-Fm4KsxwUy09CUSxiebkEpi parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-FnjU7A0vl9pKTDUEyOHZUN
    recaptcha-0.1.0.4-IC9NyRWqKicMJ72hGBxhH
    safe-0.3.21-81OBzhiiBKY2n0K6LFtGQC
    skylighting-0.14.4-K6lqbKrS924Ams4lI6jaAJ
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-3hnWhpJZuWdE2NXpC0N7hI
    tagsoup-0.14.8-FSXz553IlPYJfSxsqYHHSH
    temporary-1.3-7AWwGtWBR6G7ykOt23PX0l text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-Is1g2k27x899cWIPdo6oxG
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16-CQzxGbacRp7KFqewtFFz03 xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-IIFbMOPwY0T7TPa6DvqRHL
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-8dU9mtpIqzSFuy56i4lrt2
    zlib-0.7.0.0-EOUuWLhP4nF34rRPrIyYfG

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

